@@ -29,7 +29,7 @@ void GetDirections(TMatrix *directions, unsigned int k, unsigned int d){
 	}
 }
 
-void GetProjections(TMatrix points, TMatrix directions, TMatrix *projections){
+void GetProjections(TMatrix& points, TMatrix& directions, TMatrix *projections){
 	int d = points[0].size();
 	int n = points.size();
 	int k = directions.size();
